//   _______    ________  _______    ______   ______   ______   _________
// /_______/\  /_______/\/______/\  /_____/\ /_____/\ /_____/\ /________/\
// \::: _  \ \ \__.::._\/\::::__\/__\::::_\/_\:::_ \ \\:::_ \ \\__.::.__\/
//  \::(_)  \/_   \::\ \  \:\ /____/\\:\/___/\\:\ \ \ \\:\ \ \ \  \::\ \
//   \::  _  \ \  _\::\ \__\:\\_  _\/ \:::._\/ \:\ \ \ \\:\ \ \ \  \::\ \
//    \::(_)  \ \/__\::\__/\\:\_\ \ \  \:\ \    \:\_\ \ \\:\_\ \ \  \::\ \
//     \_______\/\________\/ \_____\/   \_\/     \_____\/ \_____\/   \__\/
// 		   _________________________________________________________________
// 		  /________________________________________________________________/\
// 		  \________________________________________________________________\/
// PURPOSE -----
// Looks through the page's markup to identify footnote links/ content.
// It then creates footnote buttons in place of the footnote links and hides the content.
// Finally, creates and positions footnotes when the generated buttons are pressed.
// IN ----------
// An optional object literal specifying script settings.
// OUT ---------
// Returns an object with the following methods:
// close: closes footnotes matching the jQuery selector passed to the function.
// activate: activates the footnote button matching the jQuery selector passed to the function.
// INFO --------
// Developed and maintained by Chris Sauve (http://pxldot.com)
// Documentation, license, and other information can be found at http://cmsauve.com/projects/bigfoot.
// TODO --------
// - Better handling of hover
// - Ability to position/ size popover relative to a containing element (rather than the window)
// - Compensate for zoom position on mobile
// KNOWN ISSUES -
// - Safari 7 doesn't properly calculate the scrollheight of the content wrapper and, as a result, will not
//		properly indicate a scrollable footnote
// - Popovers that are instantiated at a smaller font size which is then resized to a larger one won't adhere
//		to your chosen max-height (in CSS) since JS tries to keep it from running off the top/ bottom of the page
//		but does so using pixel values tied to the sizes of the footnote content when it was originally activated.
//		If anyone has any ideas on this, please let me know!
(function(e){e.bigfoot=function(t){function i(t,n){var r,i,s,o;t.each(function(){var t=e(this);s="#"+t.attr("href").split("#")[1];r=t.closest("sup");i=t.find("sup");if(r.length>0){o=(r.attr("id")||"")+(t.attr("id")||"");n.push(r.attr({"data-footnote-backlink-ref":o,"data-footnote-ref":s}))}else if(i.length>0){o=(i.attr("id")||"")+(t.attr("id")||"");n.push(t.attr({"data-footnote-backlink-ref":o,"data-footnote-ref":s}))}else{o=t.attr("id")||"";n.push(t.attr({"data-footnote-backlink-ref":o,"data-footnote-ref":s}))}})}function s(e){if(e.is(":empty")||e.children(":not(.hidden)").length==0){var t=e.parent();n.actionOriginalFN.toLowerCase()==="delete"?e.remove():e.addClass("hidden").css({display:"none"});s(t)}else if(e.children(":not(.hidden)").length==e.children("hr:not(.hidden)").length){var t=e.parent();if(n.actionOriginalFN.toLowerCase()==="delete")e.remove();else{e.children("hr").addClass("hidden").css({display:"none"});e.addClass("hidden").css({display:"none"})}s(t)}}function o(e,t){t.indexOf(" ")>=0&&(t=t.trim().replace(/ +/g,"|").replace(/(.*)/g,"($1)"));var n="(s|&nbsp;)*<s*a[^#<]*#"+t+"[^>]*>(.*?)<s*/s*a>",r=new RegExp(n,"g");return e.replace(r,"").replace("[]","")}function u(e,t,n){var r=new RegExp("{{"+t+":([^}]*)}}","g"),i,s,o;while(i=r.exec(e))if(i[1]){s=n.attr(i[1])||"";e=e.replace("{{"+t+":"+i[1]+"}}",s)}return e}function d(t,r){t=t||".footnote-content";r=r||n.popoverDeleteDelay;e(t).each(function(){var t=e('.footnote-button[data-footnote-identifier="'+e(this).attr("data-footnote-identifier")+'"]'),n=e(this);if(t.hasClass("changing"))return;t.removeClass("active hover-instantiated click-instantiated").addClass("changing");n.removeClass("active").addClass("disapearing");setTimeout(function(){n.remove();t.removeClass("changing")},r)});return e(t.replace(".footnote-content",".footnote-button"))}function m(e,t){t=t||.5;var n=e.find(".tooltip");n.length>0&&n.css({left:t*100+"%"})}function g(t){var n=parseFloat(t.outerWidth()),r=parseFloat(t.outerHeight()),i=y(),s=t.offset().top-e(window).scrollTop()+r/2,o=t.offset().left+n/2;return{topRoom:s,bottomRoom:i.height-s,leftRoom:o,rightRoom:i.width-o,leftRelative:o/i.width,topRelative:s/i.height}}function y(){var e=document.createElement("div");e.style.cssText="position: fixed;top: 0;left: 0;bottom: 0;right: 0;";document.documentElement.insertBefore(e,document.documentElement.firstChild);var t={width:e.offsetWidth,height:e.offsetHeight};document.documentElement.removeChild(e);return t}var n=e.extend({actionOriginalFN:"hide",activateOnHover:!1,allowMultipleFN:!1,appendPopoversTo:undefined,deleteOnUnhover:!1,hoverDelay:250,popoverDeleteDelay:500,popoverCreateDelay:100,positionNextToBlock:!0,positionContent:!0,preventPageScroll:!0,scope:!1,contentMarkup:'<aside class="footnote-content bottom"data-footnote-identifier="{{FOOTNOTENUM}}" alt="Footnote {{FOOTNOTENUM}}"><div class="footnote-main-wrapper"><div class="footnote-content-wrapper">{{FOOTNOTECONTENT}}</div></div><div class="tooltip"></div></aside>',buttonMarkup:'<a href="#" class="footnote-button" data-footnote-identifier="{{FOOTNOTENUM}}" alt="See Footnote {{FOOTNOTENUM}}" rel="footnote"data-footnote-content="{{FOOTNOTECONTENT}}"><span class="footnote-circle" data-footnote-identifier="{{FOOTNOTENUM}}"></span><span class="footnote-circle"></span><span class="footnote-circle"></span></a>'},t),r=function(){var t;t=n.scope?n.scope+' a[href*="#"]':'a[href*="#"]';var r=e(t).filter(function(){var t=e(this),n=t.attr("rel");if(!n||n=="null")n="";return(t.attr("href")+n).match(/(fn|footnote|note)[:\-_\d]/gi)&&t.closest("[class*=footnote]:not(a):not(sup)").length<1}),a=[],f=[],l=[],c,h;i(r,f);e(f).each(function(){c=e(this).attr("data-footnote-ref").replace(":","\\:");h=e(c).closest("li");if(h.length>0){a.push(h);l.push(this)}});for(var p=0;p<a.length;p++){var d=o(e(a[p]).html().trim(),e(l[p]).data("footnote-backlink-ref")).replace(/"/g,"&quot;").replace(/&lt;/g,"&ltsym;").replace(/&gt;/g,"&gtsym;"),v=+(p+1),m="",g;d.indexOf("<")!==0&&(d="<p>"+d+"</p>");m=n.buttonMarkup.replace(/\{\{FOOTNOTENUM\}\}/g,v).replace(/\{\{FOOTNOTECONTENT\}\}/g,d);m=u(m,"SUP",e(l[p]));m=u(m,"FN",e(a[p]));g=e(m).insertAfter(e(l[p]));e(l[p]).remove();var y=e(a[p]).parent();switch(n.actionOriginalFN.toLowerCase()){case"delete":e(a[p]).remove();s(y);break;case"hide":e(a[p]).addClass("hidden").css({display:"none"});s(y)}}},a=function(t){if(n.activateOnHover){var r=e(t.target).closest(".footnote-button"),i='[data-footnote-identifier="'+r.attr("data-footnote-identifier")+'"]';if(r.hasClass("active"))return;r.addClass("hover-instantiated");if(!n.allowMultipleFN){var s=".footnote-content:not("+i+")";d(s)}c(".footnote-button"+i).addClass("hover-instantiated")}},f=function(t){var n=e(t.target),r=n.closest(".footnote-button");$nearFootnote=n.closest(".footnote-content");if(r.length>0){t.preventDefault();l(r)}else $nearFootnote.length<1&&e(".footnote-content").length>0&&d()},l=function(e){e.blur();var t='data-footnote-identifier="'+e.attr("data-footnote-identifier")+'"';if(e.hasClass("changing"))return;if(!e.hasClass("active")){e.addClass("changing");setTimeout(function(){e.removeClass("changing")},n.popoverCreateDelay);c(".footnote-button["+t+"]");e.addClass("click-instantiated");n.allowMultipleFN||d(".footnote-content:not(["+t+"])")}else n.allowMultipleFN?d(".footnote-content["+t+"]"):d()},c=function(t){t=t||".footnote-button";if(n.allowMultipleFN)var r=e(t).closest(".footnote-button");else var r=e(t+":first").closest(".footnote-button");r.each(function(){var t=e(this);try{var r=n.contentMarkup.replace(/\{\{FOOTNOTENUM\}\}/g,t.attr("data-footnote-identifier")).replace(/\{\{FOOTNOTECONTENT\}\}/g,t.attr("data-footnote-content").replace(/&gtsym;/,"&gt;").replace(/&ltsym;/,"&lt;"));r=u(r,"BUTTON",t)}finally{if(!n.appendPopoversTo){$nearestBlock=t.closest("p, div, pre, li, ul, section, article, main, aside");$siblingFootnote=$nearestBlock.siblings(".footnote-content:last");$siblingFootnote.length>0?$content=e(r).insertAfter($siblingFootnote):$content=e(r).insertAfter($nearestBlock)}else $content=e(r).appendTo(n.appendPopoversTo+":first");$content.attr("data-bigfoot-max-height",$content.height());v();t.addClass("active");$content.find(".footnote-content-wrapper").bindScrollHandler()}});var i=e(t.replace(".footnote-button",".footnote-content"));setTimeout(function(){i.addClass("active")},n.popoverCreateDelay);return i};e.fn.bindScrollHandler=function(){if(!n.preventPageScroll)return;e(this).on("DOMMouseScroll mousewheel",function(t){var n=e(this),r=n.scrollTop(),i=n[0].scrollHeight,s=parseInt(n.css("height")),o=n.closest(".footnote-content");n.scrollTop()>0&&n.scrollTop()<10&&o.addClass("scrollable");if(!o.hasClass("scrollable"))return;var u=t.type=="DOMMouseScroll"?t.originalEvent.detail*-40:t.originalEvent.wheelDelta,a=u>0,f=function(){t.stopPropagation();t.preventDefault();t.returnValue=!1;return!1};if(!a&&-u>i-s-r){n.scrollTop(i);o.addClass("fully-scrolled");return f()}if(a&&u>r){n.scrollTop(0);o.removeClass("fully-scrolled");return f()}o.removeClass("fully-scrolled")})};var h=function(t){n.deleteOnUnhover&&n.activateOnHover&&setTimeout(function(){var n=e(t.target).closest(".footnote-content, .footnote-button");e(".footnote-button:hover, .footnote-content:hover").length<1&&d()},n.hoverDelay)},p=function(e){e.keyCode==27&&d()},v=function(){n.positionContent&&e(".footnote-content").each(function(){var t=e(this),n='data-footnote-identifier="'+t.attr("data-footnote-identifier")+'"',r=t.find(".footnote-content-wrapper"),i=e(".footnote-button["+n+"]"),s=g(i),o=parseFloat(t.css("width")),u=parseFloat(t.css("margin-top")),a=+t.attr("data-bigfoot-max-height"),f=2*u+a,l=1e4;if(s.bottomRoom<f&&s.topRoom>s.bottomRoom){t.css({top:"auto",bottom:s.bottomRoom+"px"}).addClass("top").removeClass("bottom");l=s.topRoom-u-15;t.css({"transform-origin":s.leftRelative*100+"% 100%"})}else{t.css({bottom:"auto",top:s.topRoom+"px"}).addClass("bottom").removeClass("top");l=s.bottomRoom-u-15;t.css({"transform-origin":s.leftRelative*100+"% 0%"})}t.find(".footnote-content-wrapper").css({"max-height":Math.min(l,a)+"px"});t.css({left:s.leftRoom-s.leftRelative*o+"px"});m(t,s.leftRelative);parseInt(t.css("height"))<t.find(".footnote-content-wrapper")[0].scrollHeight&&t.addClass("scrollable")})},b=function(e,t){var r=n[e];n[e]=t;return r},w=function(e){return n[e]};e(document).ready(function(){r();e(document).on("mouseenter",".footnote-button",a);e(document).on("touchend click",f);e(document).on("mouseout",".hover-instantiated",h);e(document).on("keyup",p);e(window).on("scroll resize",v)});return{close:function(e,t){return d(e,t)},activate:function(e){return c(e)},reposition:function(){return v()},getSetting:function(e){return w(e)},updateSetting:function(e,t){return b(e,t)}}}})(jQuery);